## Summary

<!-- Brief description of changes -->

## Type of Change

<!-- Mark relevant items with [x] -->

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)

## Related Issues

<!-- Link to related issues: Fixes #123, Relates to #456 -->

## Changes Made

<!-- List the main changes -->

-
-
-

## Testing

<!-- Describe how you tested these changes -->

- [ ] Existing tests pass (`pytest`)
- [ ] New tests added for new functionality
- [ ] Manual testing performed

## Checklist

<!-- Ensure all items are complete -->

- [ ] Code follows project style (run `ruff check` and `ruff format`)
- [ ] Type hints added for new code
- [ ] Documentation updated (if applicable)
- [ ] CHANGELOG.md updated under `[Unreleased]`
- [ ] No secrets or credentials included

## Screenshots/Output

<!-- If applicable, add screenshots or command output -->

## Additional Notes

<!-- Any additional context for reviewers -->
